==> geopsypack-src-3.3.5.tar.gz: geopsypack-src-3.3.5/ArrayCore/src/HRFKDirectRayleighRadial.h <==
/***************************************************************************
**
**  This file is part of ArrayCore.
**
**  ArrayCore is free software: you can redistribute it and/or modify
**  it under the terms of the GNU General Public License as published by
**  the Free Software Foundation, either version 3 of the License, or
**  (at your option) any later version.
**
**  ArrayCore is distributed in the hope that it will be useful,
**  but WITHOUT ANY WARRANTY; without even the implied warranty of
**  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
**  GNU General Public License for more details.
**
**  You should have received a copy of the GNU General Public License
**  along with Foobar.  If not, see <http://www.gnu.org/licenses/>
**
**  See http://www.geopsy.org for more information.
**
**  Created: 2018-07-12
**  Copyright: 2018-2019
**    Marc Wathelet (ISTerre, Grenoble, France)
**
***************************************************************************/

#ifndef HRFKDIRECTRAYLEIGHRADIAL_H
#define HRFKDIRECTRAYLEIGHRADIAL_H

#include "HRFKDirectRayleigh.h"
#include "ArrayCoreDLLExport.h"

namespace ArrayCore {

  class ARRAYCORE_EXPORT HRFKDirectRayleighRadial : public HRFKDirectRayleigh
  {
  public:
    HRFKDirectRayleighRadial(FKCache * gridCache)
      : HRFKDirectRayleigh(gridCache) {}

    virtual double value(const Point& kell, int index) const;
    virtual double value(const Point& kell) const;

    virtual double ellipticity(const Point& kell);
  };

} // namespace ArrayCore

#endif // HRFKDIRECTRAYLEIGHRADIAL_H

==> geopsypack-src-3.4.1.tar.gz: geopsypack-src-3.4.1/ArrayCore/src/HRFKDirectRayleighRadial.h <==
/***************************************************************************
**
**  This file is part of ArrayCore.
**
**  ArrayCore is free software: you can redistribute it and/or modify
**  it under the terms of the GNU General Public License as published by
**  the Free Software Foundation, either version 3 of the License, or
**  (at your option) any later version.
**
**  ArrayCore is distributed in the hope that it will be useful,
**  but WITHOUT ANY WARRANTY; without even the implied warranty of
**  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
**  GNU General Public License for more details.
**
**  You should have received a copy of the GNU General Public License
**  along with Foobar.  If not, see <http://www.gnu.org/licenses/>
**
**  See http://www.geopsy.org for more information.
**
**  Created: 2018-07-12
**  Copyright: 2018-2019
**    Marc Wathelet (ISTerre, Grenoble, France)
**
***************************************************************************/

#ifndef HRFKDIRECTRAYLEIGHRADIAL_H
#define HRFKDIRECTRAYLEIGHRADIAL_H

#include "HRFKDirectRayleigh.h"
#include "ArrayCoreDLLExport.h"

namespace ArrayCore {

  class ARRAYCORE_EXPORT HRFKDirectRayleighRadial : public HRFKDirectRayleigh
  {
  public:
    HRFKDirectRayleighRadial(FKCache * gridCache)
      : HRFKDirectRayleigh(gridCache) {}

    virtual double value(const Point& kell, int index) const;
    virtual double value(const Point& kell) const;

    virtual double ellipticity(const Point& kell, bool& ok);
  };

} // namespace ArrayCore

#endif // HRFKDIRECTRAYLEIGHRADIAL_H
